@@ -8,8 +8,7 @@ urlpatterns = patterns('tendenci.apps.invoices.views',
         {'template_name': 'invoices/print_view.html'}, name="invoice.print_view"),
     url(r'^adjust/(?P<id>\d+)/$',             'adjust', name="invoice.adjust"),
     url(r'^detail/(?P<id>\d+)/$',             'detail', name="invoice.detail"),
-    url(r'^make-offline-payment/(?P<id>\d+)/$', 'make_offline_payment', name="invoice.make_offline_payment"),
-    url(r'^mark_as_paid/(?P<id>\d+)/$', 'mark_as_paid', name="invoice.mark_as_paid"),
+    url(r'^mark-as-paid/(?P<id>\d+)/$', 'mark_as_paid', name="invoice.mark_as_paid"),
     url(r'^void_payment/(?P<id>\d+)/$', 'void_payment', name="invoice.void_payment"),
     url(r'^search/$',                         'search', name="invoice.search"),
     # invoice reports
